==> skypager-collection-5.0.2.tgz: package/src/document/index.js <==
import url from 'url'
import { basename, resolve, relative } from 'path'
import { mixinPropertyUtils } from 'skypager-util'
import isAbsolutePath from 'path-is-absolute'
import Collection from '../collection'
import mapValues from 'lodash/mapValues'

export const DefaultPatterns = [
  '**/*.{js,md,yml,json,svg,html,css,scss,less,json}',
  '!node_modules/**'
]

export const patterns = DefaultPatterns

export class Document {

  static fs = require('mem-fs').create();

  static patterns = DefaultPatterns;

  static mountCollection(basePath = process.cwd(), options = {}) {
    return Collection.mount(basePath, options)
  }

  static get stringUtils() {
    return Collection.stringUtils
  }

  constructor (vFileOrPath, options = {}) {
    mixinPropertyUtils(this)

    const originalURI = normalizeUri(
      vFileOrPath.path ? vFileOrPath.path : vFileOrPath
    )

    this.hide('options', options)
    this.hide('originalURI', originalURI)
    this.hide('parsedURI', url.parse(this.originalURI))
    this.hide('url', this.parsedURI.href)
    this.hide('uri', this.url)
    this.hide('path', this.parsedURI.path)
    this.hide('fs', this.constructor.fs)

    this.lazy('file', () => this.readFile())

    this.hide('data', {})

    this.id = this.baseRelativePath
      .replace(/\.\w+$/g, '')
      .replace(/\.js$/g,'')
  }

  get metadata() {
    return {
      ...this.fileData,
      ...this.data,
    }
  }

  get idPair() {
    return [this.id, this]
  }

  get isIndex() {
    return !!(this.id.match(/index$/) || this.file.basename === 'index.js')
  }

  get variationsBase() {
    return this.isIndex
      ? this.fileDirnameBasename
      : this.fileStem
  }

  get fileExtname() {
    return this.file.extname
  }

  createStemVariations (base = this.variationsBase, options = {}) {
    const { startCase, camelCase, kebabCase, snakeCase } = this.constructor.stringUtils

    return mapValues({
      classified: startCase(camelCase(base)).replace(/\s+/g,''),
      camel: camelCase(base),
      kebab: kebabCase(base),
      snake: snakeCase(base),
      underscored: kebabCase(base).replace(/\-/g,'_')
    }, (v) => `${options.prefix || ''}${v}${options.suffix || ''}`)
  }

  get fileData () {
    return this.file.data
  }

  get fileMessages () {
    return this.file.messages
  }

  get variations () {
    return this.createStemVariations(this.variationsBase)
  }

  get nameVariations() {
    return Object.values(this.variations)
  }

  get indexVariations() {
    return this.createStemVariations(this.variationsBase, {
      suffix: `/index${this.fileExtname}`,
    })
  }

  get filenameVariations() {
    return this.createStemVariations(this.variationsBase, {
      suffix: this.fileExtname,
    })
  }

  get fileStem() {
    return this.file.stem
  }

  get fileBaseName() {
    return this.file.basename
  }

  get fileDirname () {
    return this.file.dirname
  }

  get fileDirnameBasename () {
    return basename(this.fileDirname)
  }

  readFile() {
    return this.fs.get(this.path)
  }

  get baseRelativePath() {
    return relative(
      this.options.base || process.cwd(),
      this.path
    )
  }

  get cacheKey() {
    return this.file
      ? [Math.floor(this.stat.mtime / 100), this.stat.size].join(':')
      : this.id
  }

  get isRemote() {
    return this.uri.protocol.indexOf('http') !== -1
  }
}

export default Document

export function buildDocumentId (url, base = process.cwd()) {
  return url.parse(url).pathname.replace(base, '')
}

export function normalizeUri (input) {
  if (typeof input !== 'string') {
    throw('Must pass the URI as a string')
  }

  const parsed = url.parse(input)

  const isFilePath = parsed.protocol === null || parsed.protocol.indexOf('file') !== -1
  const isRemoteUrl = !isFilePath && parsed.protocol.indexOf('http') !== -1
  const isAbsoluteFilePath = isFilePath && isAbsolutePath(parsed.path)

  if (isRemoteUrl) {
    return url.format(parsed)
  }

  if (isFilePath && isAbsoluteFilePath) {
    return url.format({
      protocol: 'file:',
      slashes: true,
      pathname: parsed.path,
    })
  } else {
    return url.format({
      protocol: 'file:',
      slashes: true,
      pathname: resolve(process.cwd(), parsed.path),
    })
  }

  return input
}

==> skypager-collection-5.5.0.tgz: package/src/document/index.js <==
import url from 'url'
import { basename, resolve, relative } from 'path'
import { mixinPropertyUtils } from 'skypager-util'
import isAbsolutePath from 'path-is-absolute'
import Collection from '../collection'
import mapValues from 'lodash/mapValues'
import vfile from 'vfile'

export const DefaultPatterns = [
  '**/*.{js,md,yml,json,svg,html,css,scss,less,json}',
  '!node_modules/**'
]

export const patterns = DefaultPatterns

export class Document {
  static fs = require('mem-fs').create();

  static patterns = DefaultPatterns;

  static mountCollection(context = process.cwd(), options = {}) {
    return Collection.mount(context, options)
  }

  static get stringUtils() {
    return Collection.stringUtils
  }

  constructor (vFileOrPath, options = {}) {
    mixinPropertyUtils(this)

    const originalURI = normalizeUri(
      vFileOrPath.path ? vFileOrPath.path : vFileOrPath,
      options.context || process.cwd()
    )

    this.hide('options', options)
    this.hide('context', options.context)
    this.hide('originalURI', originalURI)
    this.hide('parsedURI', url.parse(this.originalURI))
    this.hide('url', this.parsedURI.href)
    this.hide('uri', this.url)
    this.hide('path', this.parsedURI.path)
    this.hide('fs', this.constructor.fs)

    this.lazy('file', () => this.createFile({
      context: this.context,
      ...(this.options.file || {})
    }))

    this.hide('data', {})

    this.id = this.baseRelativePath
      .replace(/\.\w+$/g, '')
      .replace(/\.js$/g,'')
  }

  createFile(fileOptions = {}) {
    return vfile({
      path: this.path,
      ...fileOptions,
    })
  }

  readFile() {
    const file = this.file
    const raw = this.loadFile()
    file.contents = raw.contents

    return this
  }

  loadFile () {
    return this.fs.get(this.path)
  }

  get metadata() {
    return {
      ...this.fileData,
      ...this.data,
    }
  }

  get idPair() {
    return [this.id, this]
  }

  get isIndex() {
    return !!(this.id.match(/index$/) || this.file.basename === 'index.js')
  }

  get variationsBase() {
    return this.isIndex
      ? this.fileDirnameBasename
      : this.fileStem
  }

  get fileExtname() {
    return this.file.extname
  }

  createStemVariations (base = this.variationsBase, options = {}) {
    const { startCase, camelCase, kebabCase, snakeCase } = this.constructor.stringUtils

    return mapValues({
      classified: startCase(camelCase(base)).replace(/\s+/g,''),
      camel: camelCase(base),
      kebab: kebabCase(base),
      snake: snakeCase(base),
      underscored: kebabCase(base).replace(/\-/g,'_')
    }, (v) => `${options.prefix || ''}${v}${options.suffix || ''}`)
  }

  get fileData () {
    return this.file.data
  }

  get fileMessages () {
    return this.file.messages
  }

  get variations () {
    return this.createStemVariations(this.variationsBase)
  }

  get nameVariations() {
    return Object.values(this.variations)
  }

  get indexVariations() {
    return this.createStemVariations(this.variationsBase, {
      suffix: `/index${this.fileExtname}`,
    })
  }

  get filenameVariations() {
    return this.createStemVariations(this.variationsBase, {
      suffix: this.fileExtname,
    })
  }

  get fileStem() {
    return this.file.stem
  }

  get fileBaseName() {
    return this.file.basename
  }

  get fileDirname () {
    return this.file.dirname
  }

  get fileDirnameBasename () {
    return basename(this.fileDirname)
  }


  get baseRelativePath() {
    return relative(
      this.context,
      this.path
    )
  }

  get cacheKey() {
    return this.file
      ? [Math.floor(this.stat.mtime / 100), this.stat.size].join(':')
      : this.id
  }

  get isRemote() {
    return this.uri.protocol.indexOf('http') !== -1
  }
}

export default Document

export function normalizeUri (input, context = process.cwd()) {
  if (typeof input !== 'string') {
    throw('Must pass the URI as a string')
  }

  const parsed = url.parse(input)

  const isFilePath = parsed.protocol === null || parsed.protocol.indexOf('file') !== -1
  const isRemoteUrl = !isFilePath && parsed.protocol.indexOf('http') !== -1
  const isAbsoluteFilePath = isFilePath && isAbsolutePath(parsed.path)

  if (isRemoteUrl) {
    return url.format(parsed)
  }

  if (isFilePath && isAbsoluteFilePath) {
    return url.format({
      protocol: 'file:',
      slashes: true,
      pathname: parsed.path,
    })
  } else {
    return url.format({
      protocol: 'file:',
      slashes: true,
      pathname: resolve(context, parsed.path),
    })
  }

  return input
}
